//
//  ViewController.swift
//  AmpChromecastSample
//
//  Created by Lopez Valenciano, Miguel on 5/5/16.
//  Copyright © 2023 Akamai. All rights reserved.
//

import UIKit
import AmpChromecast
import GoogleCast

class ViewController: UIViewController {
    
    @IBOutlet weak var tableView: UITableView!
    var videoArray = [Video]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        let castButton = GCKUICastButton(frame: CGRect(x: 0, y: 0, width: 24, height: 24))
        navigationItem.rightBarButtonItem = UIBarButtonItem(customView: castButton)
        self.parseVideos()
    }
    
    func parseVideos() {
        var metadata = GCKMediaMetadata(metadataType: .movie)
        metadata.setString("Sintel", forKey: kGCKMetadataKeyTitle)
        metadata.addImage(GCKImage(url:URL(string: "https://img00.deviantart.net/18af/i/2010/270/1/6/i_love_sintel_by_nash88-d2zkxw5.jpg")!, width: 480, height: 720))
        metadata.setString("Sintiel Video", forKey: "description")
        
        var tracks = [GCKMediaTrack]()
        
        if let captionsTrack = GCKMediaTrack(identifier: 1, contentIdentifier: "", contentType: "text/cea608", type: GCKMediaTrackType.text, textSubtype: GCKMediaTextTrackSubtype.captions, name: "English Captions", languageCode: "en", customData: nil) {
            
            tracks.append(captionsTrack)
        }
        
        let builder = GCKMediaInformationBuilder()
        builder.contentID = url
        builder.streamType = .buffered
        builder.contentType = "application/x-mpegURL"
        builder.metadata = metadata
        builder.streamDuration = TimeInterval(100)
        builder.mediaTracks = tracks
        
        var mediaItem = MediaItem(mediaInformation: builder.build())
        
        var video = Video(url: url, mediaItem: mediaItem)
        
        videoArray.append(video)
        
        metadata = GCKMediaMetadata(metadataType: .movie)
        metadata.setString("Beach", forKey: kGCKMetadataKeyTitle)
        metadata.addImage(GCKImage(url:URL(string: "https://vacationidea.com/pix/img25Hy8R/beaches/best-beaches-in-costa-rica_f.jpg")!, width: 480, height: 720))
        metadata.setString("Beach Sample", forKey: "description")
        
        let mediaInformationBuilder = GCKMediaInformationBuilder.init(contentURL: URL(string: "https://mnmedias.api.telequebec.tv/m3u8/29880.m3u8")!)
        mediaInformationBuilder.streamType = GCKMediaStreamType.buffered
        mediaInformationBuilder.contentType = "application/x-mpegurl"
        
        
        let mediaInfo = mediaInformationBuilder.build()
        
        mediaItem = MediaItem(mediaInformation: mediaInfo)
        
        video = Video(url: "https://mnmedias.api.telequebec.tv/m3u8/29880.m3u8", mediaItem: mediaItem)
        
        videoArray.append(video)
        
        
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        let index = self.tableView.indexPathForSelectedRow!
        let destinationViewController = segue.destination as! PlayerViewController
        destinationViewController.videoId = self.videoArray[index.row]
    }
    
}

extension ViewController: UITableViewDelegate {
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
    }
}

extension ViewController:UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath) as UITableViewCell
        
        cell.textLabel?.text = "Video \(indexPath.row + 1)"
        
        return cell
        
    }
}
